<?php

namespace Drupal\ada;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Http\ClientFactory;

/**
 * Class for managing ADAInfo.
 */
class ADAInfo {
  /**
   * Http client to make requests.
   *
   * @var GuzzleHttp\ClientInterface
   */
  private $client;

  /**
   * ADA installation base URL.
   *
   * @var strring
   */
  private $baseUrl;

  /**
   * ADAInfo constructor.
   *
   * @param Drupal\Core\Http\ClientFactory $factory
   *   The injected ClientFactory.
   * @param Drupal\Core\Config\ConfigFactory $configFactory
   *   The injected ConfigFactory.
   */
  public function __construct(ClientFactory $factory, ConfigFactory $configFactory) {
    $this->client = $factory->fromOptions();
    $this->baseUrl = $configFactory->get('ada.application_settings')->get('ada_url');
    if (!empty($this->baseUrl)) {
      $this->baseUrl = rtrim($this->baseUrl, '/');
    }
  }

  /**
   * Loads the list of available courses.
   *
   * @return array
   *   The array of loaded courses.
   */
  public function getCourses() {
    if (!empty($this->baseUrl)) {
      $req = $this->client->get($this->baseUrl . '/api/v1/info');
      return Json::decode($req->getBody()->getContents());
    }
    return [];
  }

}
