<?php

namespace Drupal\ada\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ApplicationSettings.
 */
class ApplicationSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ada_application_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ada.application_settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ada.application_settings');

    $instructions = "<p>This is the main ADA Drupal module. In order to communicate with ADA please configure it using this form</p>";

    $form['instructions'] = [
      '#markup' => $instructions,
    ];

    $form['ada_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Main URL of your ADA installation'),
      '#description' => $this->t('Enter the url of your ADA installation. E.g.: <a href="https://learning.lynxlab.com" target="_blank">https://learning.lynxlab.com</a>.'),
      '#default_value' => $config->get('ada_url'),
      '#validators' => [
        'url[absolute]',
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ada.application_settings')
      ->set('ada_url', $form_state->getValue('ada_url'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
